.. _Python: https://www.python.org/
.. _Django: https://www.djangoproject.com/
.. _Django REST framework: https://www.django-rest-framework.org/

============
Django Deovi
============

A Django application around Deovi

Dependancies
************

* `Python`_>=3.8;
* `Django`_>=4.0;
* `Django REST framework`_>=3.13.0;

Links
*****

* (Not yet) Read the documentation on `Read the docs <https://django-deovi.readthedocs.io/>`_;
* (Not yet) Download its `PyPi package <https://pypi.python.org/pypi/django-deovi>`_;
* Clone it on its `Github repository <https://github.com/sveetch/django-deovi>`_;
